/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor;

import java.awt.Dimension;
import java.util.Date;
import javax.swing.DefaultListModel;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import net.miginfocom.swing.MigLayout;
import org.jdesktop.swingx.JXDatePicker;
import org.jdesktop.swingx.JXPanel;
import org.openide.util.NbBundle;

/**
 *
 * @author Gerben Feenstra
 */
public class ExportSensorRunPanel extends JXPanel {

    // Bundle strings
    private static String JLABEL_FIELDS = NbBundle.getMessage(SensorModule.class, "action.exportsensorrunaverages.panelcomponent.jlabel.fields");
    private static String JLABEL_STARTDATE = NbBundle.getMessage(SensorModule.class, "action.exportsensorrunaverages.panelcomponent.jlabel.startdate");
    private static String JLABEL_ENDDATE = NbBundle.getMessage(SensorModule.class, "action.exportsensorrunaverages.panelcomponent.jlabel.enddate");
    private static String JLABEL_EXAMPLE = NbBundle.getMessage(SensorModule.class, "action.exportsensorrunaverages.panelcomponent.jlabel.example");
    private static int FIELD_SCROLLPANE_WIDTH = 150;
    private static int FIELD_SCROLLPANE_HEIGHT = 275;
    private static int RESULT_SCROLLPANE_WIDTH = 400;
    private static int RESULT_SCROLLPANE_HEIGHT = 150;
    // Panel + Components
    private JTable exampleTable = new JTable();
    private JList fieldList = new JList();
    private JXDatePicker startDatePicker = new JXDatePicker(new Date());
    private JXDatePicker endDatePicker = new JXDatePicker(new Date());
    private JScrollPane resultScrollPane;
    private JXPanel datesPanel;
    private JScrollPane fieldScrollPane;

    public ExportSensorRunPanel() {

        // Build panel
        this.setLayout(new MigLayout(
                "wrap 2",
                "[]20[]",
                "[][]20[]"));

        // row 1    
        this.add(new JLabel(JLABEL_FIELDS), "wrap");

        // row 2
        initFieldScrollPane();

        initDatePickerPanel();

        this.add(new JLabel(JLABEL_EXAMPLE));
        // Result table
        initExampleScrollPane();
    }

    /**
     * Create panel holding the datePickers
     * @return 
     */
    private void initDatePickerPanel() {
        if (datesPanel == null) {
            datesPanel = new JXPanel(new MigLayout("wrap 2"));
            datesPanel.add(new JLabel(JLABEL_STARTDATE));
            datesPanel.add(startDatePicker);
            datesPanel.add(new JLabel(JLABEL_ENDDATE));
            datesPanel.add(endDatePicker);
            add(this.datesPanel, "wrap");
        }
    }

    /**
     * Create ScrollPane containing all Fields in a FieldList. Retrieve model from controller
     * 
     * @return ScrollPane containing all Fields
     */
    private void initFieldScrollPane() {
        if (fieldScrollPane == null) {
            fieldScrollPane = new JScrollPane();
            fieldScrollPane.setPreferredSize(new Dimension(FIELD_SCROLLPANE_WIDTH, FIELD_SCROLLPANE_HEIGHT));
            fieldList.setModel(new DefaultListModel()); // Needs DefaultListModel!
            fieldScrollPane.setViewportView(fieldList);
            this.add(fieldScrollPane, "span 1 3"); // span 3rd row as well
            
        }
    }

    /**
     * Create ScrollPane containing the example table.
     * 
     * @return ScrollPane containing the example table
     */
    private void initExampleScrollPane() {
        if (resultScrollPane == null) {
            resultScrollPane = new JScrollPane();
            resultScrollPane.setPreferredSize(new Dimension(RESULT_SCROLLPANE_WIDTH, RESULT_SCROLLPANE_HEIGHT));
            exampleTable.setRowSelectionAllowed(false);
            exampleTable.setEnabled(false);
            resultScrollPane.setViewportView(exampleTable);
            this.add(resultScrollPane, "span 2 1");
        }
    }

    public JTable getExampleTable() {
        return exampleTable;
    }

    public JList getFieldList() {
        return fieldList;
    }

    public JXDatePicker getStartDatePicker() {
        return this.startDatePicker;
    }

    public JXDatePicker getEndDatePicker() {
        return this.endDatePicker;
    }
}
