/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor;

import nl.cloudfarming.client.geoviewer.Category;
import nl.cloudfarming.client.geoviewer.LayerAction;
import nl.cloudfarming.client.geoviewer.RasterLayer;
import nl.cloudfarming.client.model.SensorRun;

/**
 *
 * @author Timon Veenstra
 */
public class SensorRunLayer extends RasterLayer {

    private SensorService service;
    private SensorRun sensorRun;

    public SensorRunLayer(SensorRun sensorRun) {
        super(SensorPalette.PALLET01_04, Category.SENSOR, sensorRun.getField().getName());
        setRaster(RasterFactory.createRaster(getService().findDataForRun(sensorRun)));
        this.sensorRun = sensorRun;
    }

    @Override
    public LayerAction[] getActions() {
        //TODO[TV 20110915] check usage node also returns actions
        return new LayerAction[]{new ChangePaletteAction(), new RemoveSensorRunAction()};
    }

    protected final SensorService getService() {
        if (service == null) {
            service = new SensorService();
        }
        return service;
    }

    public void setService(SensorService service) {
        this.service = service;
    }

    @Override
    public Class getObjectClass() {
        return sensorRun.getClass();
    }
    
    public SensorRun getObject(){
        return sensorRun;
    }
}
