/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.sensor.explorer;

import java.beans.IntrospectionException;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.geoviewer.Layer;
import nl.cloudfarming.client.model.AgroSenseBeanNode;
import nl.cloudfarming.client.model.SensorDataFile;
import nl.cloudfarming.client.model.SensorRun;
import nl.cloudfarming.client.sensor.*;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Timon Veenstra
 */
public class SensorRunNode extends AgroSenseBeanNode<SensorRun> {

    public SensorRunNode(SensorRunLayer layer,SensorService service) throws IntrospectionException {
        super(layer.getObject(), Children.create(new SensorRunCF(layer),false), Lookups.fixed(layer,service));
        setIconBaseWithExtension(Layer.LAYER_NODE_ICON_BASE);
        setName(layer.getName());
    }

     @Override
    public Action[] getActions(boolean context) {
        return new Action[]{new RemoveSensorRunAction(), new ChangePaletteAction()};
    }

    private static class SensorRunCF extends ChildFactory<SensorRun> {

        private final SensorRunLayer layer; 
        
        public SensorRunCF(SensorRunLayer layer) {
            this.layer = layer;
        }

        @Override
        protected boolean createKeys(List<SensorRun> toPopulate) {
            toPopulate.add(layer.getObject());
            return true;
        }

        @Override
        protected Node createNodeForKey(SensorRun key) {
            return new AbstractNode(Children.LEAF,Lookups.fixed(new Raster(layer.getRaster())));
        }
    }      
     
}
