/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.sensor.explorer;

import java.beans.IntrospectionException;
import java.util.List;
import nl.cloudfarming.client.model.SensorRun;
import nl.cloudfarming.client.sensor.SensorEventKey;
import nl.cloudfarming.client.sensor.SensorModule;
import nl.cloudfarming.client.sensor.SensorRunLayer;
import nl.cloudfarming.client.sensor.SensorService;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventBus;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.Lookup;

/**
 *
 * @author Timon Veenstra
 */
public class SensorRunNodeFactory  extends ChildFactory<SensorRun> {

    private SensorService service;

    public SensorRunNodeFactory() {
        GuiEventBus.addListener(new GuiEventListener() {

            @Override
            public void onEvent(GuiEvent event) {
                refresh(true);
            }

            @Override
            public boolean listensTo(GuiEventKey guiEventKey) {
                return guiEventKey.equals(SensorEventKey.SENSOR_DATA_LINKED) || guiEventKey.equals(SensorEventKey.SENSOR_RUN_REMOVED);
            }

            @Override
            public String getModuleName() {
                return SensorModule.MODULE_NAME;
            }
        });
    }

    @Override
    protected Node createNodeForKey(SensorRun key) {
        try {
            SensorRunNode node = new SensorRunNode(new SensorRunLayer(key),service);
            return node;
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    protected boolean createKeys(List<SensorRun> toPopulate) {
        toPopulate.addAll(getService().findSensorRuns());
        return true;
    }

    public SensorService getService() {
        if (this.service == null) {
            this.service = Lookup.getDefault().lookup(SensorService.class);
        }
        return this.service;
    }

    public void setService(SensorService service) {
        this.service = service;
    }

}
