/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.files;

import java.util.ArrayList;
import java.util.List;
import javax.swing.table.DefaultTableModel;
import nl.cloudfarming.client.model.SensorDataFile;
import nl.cloudfarming.client.sensor.SensorModule;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra
 */
public class SensorFilesTableModel extends DefaultTableModel {

    private static final int MIN_ROW_COUNT = 1;

    private static String COLUMN_SENSOR_FILE_NR = NbBundle.getMessage(SensorModule.class, "sensor.files.sensorfiles_table_model.column_sensor_file_nr");
    private static String COLUMN_CHECKSUM = NbBundle.getMessage(SensorModule.class, "sensor.files.sensorfiles_table_model.column_checksum");
    private static String COLUMN_FILE_NAME = NbBundle.getMessage(SensorModule.class, "sensor.files.sensorfiles_table_model.column_file_name");
    private static String COLUMN_FILE_CREATED = NbBundle.getMessage(SensorModule.class, "sensor.files.sensorfiles_table_model.column_file_created");
    private static String COLUMN_FILE_READ = NbBundle.getMessage(SensorModule.class, "sensor.files.sensorfiles_table_model.column_file_read");
        
    public SensorFilesTableModel() {
        addColumn(COLUMN_SENSOR_FILE_NR);
        addColumn(COLUMN_CHECKSUM);
        addColumn(COLUMN_FILE_NAME);
        addColumn(COLUMN_FILE_CREATED);
        addColumn(COLUMN_FILE_READ);
        updateContent(null);
    }

    public final void updateContent(List<SensorDataFile> sensorFiles) {
        for (int i = 0; i < getRowCount(); i++) {
            removeRow(i);
        }
        
        if (sensorFiles != null) {
            int rowCount = 0;
            for (SensorDataFile sensorFile : sensorFiles) {
                List<Object> row = new ArrayList<Object>();

                row.add(sensorFile.getId());
                row.add(sensorFile.getChecksum());
                row.add(sensorFile.getFileName());
                row.add(sensorFile.getFileCreated());
                row.add(sensorFile.getFileRead());

                addRow(row.toArray());
                rowCount++;
            }
        }
        setRowCount(MIN_ROW_COUNT);

    }
}
